package robotrace;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import static javax.media.opengl.GL.*;
import javax.media.opengl.GL2;
import static javax.media.opengl.GL2GL3.GL_TEXTURE_1D;

/**
 *
 * @author Rick Hendricksen
 */
public class Texture1D {
    public int textureID;
    
    /**
     * Creates a new 1D - texture.
     * 
     * @modifies Disables GL_TEXTURE_2D and enables GL_TEXTURE_1D
     * @param gl
     * @param colors
     */
    public Texture1D(GL2 gl, Vector[] colors){
        gl.glDisable(GL_TEXTURE_2D);
        gl.glEnable(GL_TEXTURE_1D);
        int[] texid = new int[]{-1};
        gl.glGenTextures(1, texid, 0);
        
        ByteBuffer bb = ByteBuffer.allocateDirect(colors.length * 4).order(ByteOrder.nativeOrder());
        for (Vector color : colors) {
           bb.put((byte) (255 * color.x)); // Red component
           bb.put((byte) (255 * color.y)); // Green component
           bb.put((byte) (255 * color.z)); // Blue component
           bb.put((byte) (255));           // Alpha component
        }
        bb.flip();
        gl.glBindTexture(GL_TEXTURE_1D, texid[0]);
        gl.glTexImage1D(GL_TEXTURE_1D, 0, GL_RGBA8, colors.length, 0, GL_RGBA, GL_UNSIGNED_BYTE, bb);
        gl.glTexParameteri(GL_TEXTURE_1D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        gl.glTexParameteri(GL_TEXTURE_1D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
        gl.glBindTexture(GL_TEXTURE_1D, 0);
        textureID = texid[0];
    }
    
    /**
     * Make sure to disable GL_TEXTURE_2D and enable GL_TEXTURE_1D before calling this method.
     * @param gl 
     */
    public void bind(GL2 gl){
        gl.glBindTexture(GL_TEXTURE_1D, textureID);
    }
    
    public static void unbind(GL2 gl){
        gl.glBindTexture(GL_TEXTURE_1D, 0);
    }
}